@@ -70,6 +70,7 @@ struct xccdf_session {
 	const char *filename;				///< File name of SCAP (SDS or XCCDF) file for this session.
 	struct oscap_list *rules;
 	struct oscap_list *skip_rules;
+	const char *reference_parameter;
 	struct oscap_source *source;                    ///< Main source assigned with the main file (SDS or XCCDF)
 	char *temp_dir;					///< Temp directory used for decomposed component files.
 	struct {
@@ -362,6 +363,40 @@ void xccdf_session_free(struct xccdf_session *session)
 	free(session);
 }
 
+static void _xccdf_session_reset_oval_agents_syschar(struct xccdf_session *session)
+{
+	if (session->oval.agents != NULL) {
+		for (int i=0; session->oval.agents[i]; i++) {
+			oval_agent_reset_syschar(session->oval.agents[i]);
+		}
+	}
+}
+
+static void _xccdf_session_reset_oval_agents_results(struct xccdf_session *session)
+{
+	if (session->oval.agents != NULL) {
+		for (int i=0; session->oval.agents[i]; i++) {
+			oval_agent_reset_results(session->oval.agents[i]);
+		}
+	}
+}
+
+void xccdf_session_result_reset(struct xccdf_session *session)
+{
+	if (session->xccdf.policy_model != NULL) {
+		oscap_list_free(session->xccdf.policy_model->policies, (oscap_destruct_func) xccdf_policy_free);
+		session->xccdf.policy_model->policies = oscap_list_new();
+	}
+
+	oscap_list_free(session->rules, (oscap_destruct_func) free);
+	session->rules = oscap_list_new();
+	oscap_list_free(session->skip_rules, (oscap_destruct_func) free);
+	session->skip_rules = oscap_list_new();
+
+	_xccdf_session_reset_oval_agents_syschar(session);
+	_xccdf_session_reset_oval_agents_results(session);
+}
+
 const char *xccdf_session_get_filename(const struct xccdf_session *session)
 {
 	return oscap_source_readable_origin(session->source);
@@ -467,6 +502,11 @@ void xccdf_session_set_user_tailoring_file(struct xccdf_session *session, const
 		oscap_source_new_from_file(user_tailoring_file) : NULL;
 }
 
+struct oscap_source *xccdf_session_get_user_tailoring_file(struct xccdf_session *session)
+{
+	return session->tailoring.user_file;
+}
+
 void xccdf_session_set_user_tailoring_cid(struct xccdf_session *session, const char *user_tailoring_cid)
 {
 	free(session->tailoring.user_component_id);
@@ -910,6 +950,7 @@ int xccdf_session_load_cpe(struct xccdf_session *session)
 	}
 
 	if (xccdf_session_is_sds(session)) {
+		_connect_cpe_session_with_sds(session);
 		struct ds_sds_index *sds_idx = xccdf_session_get_sds_idx(session);
 		if (sds_idx == NULL) {
 			return -1;
@@ -928,7 +969,6 @@ int xccdf_session_load_cpe(struct xccdf_session *session)
 				oscap_string_iterator_free(cpe_it);
 				return 1;
 			}
-			_connect_cpe_session_with_sds(session);
 			while (oscap_string_iterator_has_more(cpe_it)) {
 				const char* cpe_filename = oscap_string_iterator_next(cpe_it);
 
@@ -1350,6 +1390,9 @@ int xccdf_session_evaluate(struct xccdf_session *session)
 	}
 	oscap_iterator_free(sit);
 
+	if (session->reference_parameter) {
+		xccdf_policy_set_reference_filter(policy, session->reference_parameter);
+	}
 	session->xccdf.result = xccdf_policy_evaluate(policy);
 	if (session->xccdf.result == NULL)
 		return 1;
@@ -1863,6 +1906,11 @@ bool xccdf_session_contains_fail_result(const struct xccdf_session *session)
 	return false;
 }
 
+struct xccdf_rule_result_iterator *xccdf_session_get_rule_results(const struct xccdf_session *session)
+{
+	return xccdf_result_get_rule_results(session->xccdf.result);
+}
+
 int xccdf_session_remediate(struct xccdf_session *session)
 {
 	int res = 0;
@@ -2020,3 +2068,8 @@ cleanup:
 	oscap_source_free(arf_source);
 	return ret;
 }
+
+void xccdf_session_set_reference_filter(struct xccdf_session *session, const char *reference_filter)
+{
+	session->reference_parameter = reference_filter;
+}
