@@ -363,8 +363,10 @@ static inline void *oscap_aligned_malloc(size_t size, size_t alignment) {
 	return _aligned_malloc(size, alignment);
 #else
 	void *ptr = NULL;
-	posix_memalign(&ptr, alignment, size);
-	return ptr;
+	int ret = posix_memalign(&ptr, alignment, size);
+	if (ret == 0)
+		return ptr;
+	return NULL;
 #endif
 }
 
@@ -382,6 +384,18 @@ char *oscap_trim(char *str);
 /// Print to a newly allocated string using a va_list.
 char *oscap_vsprintf(const char *fmt, va_list ap);
 
+/**
+ * Generates a pseudorandom string of a given length.
+ * If charset string is not NULL and its length is greater than 0,
+ * it will be used as a dictionary, otherwise a default alphanumeric set
+ * will be the base for the generated string.
+ * Caller is responsible for freeing the returned string.
+ * @param len desired string length (must be greater than 0)
+ * @param charset a dictionary string, could be NULL
+ * @return A random string of desired length.
+ */
+char *oscap_generate_random_string(size_t len, char *charset);
+
 /**
  * Join 2 paths in an intelligent way.
  * Both paths are allowed to be NULL.
@@ -540,4 +554,21 @@ char *oscap_windows_error_message(unsigned long error_code);
  */
 int oscap_open_writable(const char *filename);
 
+/**
+ * Check if a path starts with the given prefix
+ * @param path file system path
+ * @param prefix file system path that will be tested if it's a prefix of the path parameter
+ * @return true or false
+ */
+bool oscap_path_startswith(const char *path, const char *prefix);
+
+/**
+ * Concatenate 2 strings
+ * Convenience wrapper over strncat.
+ * @param str1 string 1
+ * @param str2 string 2
+ * @return string 1 with string 2 appended inside
+ */
+char *oscap_concat(char *str1, char *str2);
+
 #endif              /* OSCAP_UTIL_H_ */
